@@ -19,7 +19,6 @@ import time
 from collections import OrderedDict
 from io import open
 from os import path
-from typing import TYPE_CHECKING
 
 # try to import readline, unix specific enhancement
 try:
@@ -44,7 +43,8 @@ from sphinx.util.console import (  # type: ignore
 from sphinx.util.osutil import ensuredir, make_filename
 from sphinx.util.template import SphinxRenderer
 
-if TYPE_CHECKING:
+if False:
+    # For type annotation
     from typing import Any, Callable, Dict, List, Pattern, Union  # NOQA
 
 TERM_ENCODING = getattr(sys.stdin, 'encoding', None)
