@@ -15,14 +15,14 @@ import re
 import sys
 import typing
 from collections import OrderedDict
-from typing import TYPE_CHECKING
 
 from six import PY2, PY3, StringIO, binary_type, string_types, itervalues
 from six.moves import builtins
 
 from sphinx.util import force_decode
 
-if TYPE_CHECKING:
+if False:
+    # For type annotation
     from typing import Any, Callable, Dict, List, Tuple, Type  # NOQA
 
 memory_address_re = re.compile(r' at 0x[0-9a-f]{8,16}(?=>)', re.IGNORECASE)
@@ -114,7 +114,7 @@ else:  # 2.7
             func = func.func
         if not inspect.isfunction(func):
             raise TypeError('%r is not a Python function' % func)
-        args, varargs, varkw = inspect.getargs(func.__code__)  # type: ignore
+        args, varargs, varkw = inspect.getargs(func.__code__)
         func_defaults = func.__defaults__
         if func_defaults is None:
             func_defaults = []
@@ -124,13 +124,13 @@ else:  # 2.7
             args = args[parts[0]:]
         if parts[1]:
             for arg in parts[1]:
-                i = args.index(arg) - len(args)
+                i = args.index(arg) - len(args)  # type: ignore
                 del args[i]
                 try:
                     del func_defaults[i]
                 except IndexError:
                     pass
-        return inspect.ArgSpec(args, varargs, varkw, func_defaults)
+        return inspect.ArgSpec(args, varargs, varkw, func_defaults)  # type: ignore
 
 try:
     import enum
@@ -313,7 +313,10 @@ class Signature(object):
             try:
                 self.signature = inspect.signature(subject)
             except IndexError:
-                if hasattr(subject, '_partialmethod'):  # partialmethod with no argument
+                # Until python 3.6.4, cpython has been crashed on inspection for
+                # partialmethods not having any arguments.
+                # https://bugs.python.org/issue33009
+                if hasattr(subject, '_partialmethod'):
                     self.signature = None
                     self.partialmethod_with_noargs = True
                 else:
